/*******************************************************************\

Module: Horn-clause Encoding

Author: Daniel Kroening

Date: June 2015

\*******************************************************************/

/// \file
/// Horn-clause Encoding

#include "horn_encoding.h"

#include <ostream>

void horn_encoding(
  const goto_modelt &,
  std::ostream &)
{
}
